@@ -26,6 +26,8 @@ class Burst(RoutesMixin, AppEventsMixin):
                                   get_converter=import_module_or_string)
     worker_class = ConfigAttribute('WORKER_CLASS',
                                    get_converter=import_module_or_string)
+    request_class = ConfigAttribute('REQUEST_CLASS',
+                                    get_converter=import_module_or_string)
 
     group_list = ConfigAttribute('GROUP_LIST')
 
