@@ -17,14 +17,17 @@ class StatCounter(object):
     worker_req_counter = None
     # worker回应数
     worker_rsp_counter = None
-    # 作业完成时间统计
+    # 任务丢弃统计
+    discard_tasks_counter = None
+    # 任务完成时间统计
     tasks_time_counter = None
-    # 作业时间统计标准
+    # 任务时间统计标准
     tasks_time_benchmark = None
 
     def __init__(self, tasks_time_benchmark):
         self.worker_req_counter = defaultdict(int)
         self.worker_rsp_counter = defaultdict(int)
+        self.discard_tasks_counter = defaultdict(int)
         self.tasks_time_counter = defaultdict(int)
         self.tasks_time_benchmark = tasks_time_benchmark
 
@@ -34,6 +37,9 @@ class StatCounter(object):
     def add_worker_rsp(self, group_id):
         self.worker_rsp_counter[group_id] += 1
 
+    def add_discard_task(self, group_id):
+        self.discard_tasks_counter[group_id] += 1
+
     def add_task_time(self, task_time):
         """
         添加一个新的时间
