@@ -80,6 +80,9 @@ DEFAULT_CONFIG = dict(
     # worker class
     WORKER_CLASS='burst.worker.Worker',
 
+    # request class
+    REQUEST_CLASS='burst.worker.Request',
+
     # 启动的group列表。group_id必须为数字
     GROUP_LIST=[dict(id=1, count=1)],
 
@@ -105,8 +108,8 @@ DEFAULT_CONFIG = dict(
     # proxy的每个分组的消息队列的最大长度, <=0 代表无限
     PROXY_MSG_QUEUE_MAX_SIZE=-1,
 
-    # worker<->proxy网络连接超时(秒), 包括 connect once，read once，write once
-    WORKER_CONN_TIMEOUT=3,
+    # worker<->proxy网络连接超时(秒), 包括 connect once，read once，write once. None 代表不超时
+    WORKER_CONN_TIMEOUT=None,
     # 处理task超时(秒). 超过后worker会自杀. None 代表永不超时
     WORKER_WORK_TIMEOUT=None,
     # worker重连等待时间
